# Hyperparameter Tuning Cookbook

The following is a cookbook of hyperparameter tuning recipes. It is not meant to be exhaustive, but instead act as a place to capture a number of the common patterns used in hyperparameter tuning.

[Hyperparameter Tuning Cookbook](https://sequential-parameter-optimization.github.io/Hyperparameter-Tuning-Cookbook/)
